"""This is the standard way to
   include a multiple-line comment in
   your code.
"""
def print_lol(the_list, level):
    """This is suits"""
    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            for tab_stop in range(level):
                print("\t", end="")
            print(each_item)


from setuptools import setup

setup(
    name        = 'y_nester',
    version     = '1.1.0',
    py_modules  = ['y_nester'],
    author      = 'cosmic',
    author_email= 'yangguanyu_2006@126.com',
    url         = '',
    description = 'A simple printer of nested lists',
)
